@@ -188,6 +188,7 @@ class PrimaryAPIObject(APIObject):
         self.client = client
         self._known_invalid_keys = []
         self.changes = {}
+        self.previous_request = None
 
     def __eq__(self, other):
         if isinstance(other, self.__class__):
@@ -203,6 +204,7 @@ class PrimaryAPIObject(APIObject):
             data = self.client._get(self.data['resource_url'])
             self.data.update(data)
             self.changes = {}
+            self.previous_request = self.data.get('resource_url')
 
     def save(self):
         if self.data.get('resource_url'):
@@ -232,6 +234,12 @@ class PrimaryAPIObject(APIObject):
         except KeyError:
             pass
 
+        # Object already refreshed from resource_url
+        # return default to prevent an unnecessary API call
+        if self.data.get('resource_url') == self.previous_request:
+            self._known_invalid_keys.append(key)
+            return default
+
         # Now refresh the object from its resource_url.
         # The key might exist but not be in our cache.
         self.refresh()
@@ -494,6 +502,7 @@ class Release(PrimaryAPIObject):
     credits = ListField('Artist', key='extraartists')
     labels = ListField('Label')
     companies = ListField('Label')
+    community = ObjectField("communitydetails")
 
     def __init__(self, client, dict_):
         super(Release, self).__init__(client, dict_)
@@ -877,6 +886,35 @@ class ListItem(SecondaryAPIObject):
         return '<ListItem {0!r}>'.format(self.id)
 
 
+class CommunityDetails(SecondaryAPIObject):
+    """
+    An object that wraps the "community" data found in a :class:`.Release`
+    object.
+    """
+    status = SimpleField()  #:
+    data_quality = SimpleField()  #:
+    want = SimpleField()  #:
+    have = SimpleField()  #:
+    rating = ObjectField('Rating')  #:
+    contributors = ListField("User")  #:
+    submitter = ObjectField("User")  #:
+
+    def __repr__(self):
+        return '<CommunityDetails want/have: {0!r}/{1!r}>'.format(self.want, self.have)
+
+
+class Rating(SecondaryAPIObject):
+    """
+    An object that wraps the "community.rating" data found in a
+    :class:`.Release` object.
+    """
+    count = SimpleField()  #:
+    average = SimpleField()  #:
+
+    def __repr__(self):
+        return '<Rating avg: {0!r}>'.format(self.average)
+
+
 CLASS_MAP = {
     'artist': Artist,
     'release': Release,
@@ -895,4 +933,6 @@ CLASS_MAP = {
     'wantlistitem': WantlistItem,
     'ordermessage': OrderMessage,
     'collectionvalue': CollectionValue,
+    'communitydetails': CommunityDetails,
+    'rating': Rating,
 }
